@@ -7,11 +7,12 @@ from scipy.stats import norm
 import matplotlib.pyplot as plt
 import seaborn as sns
 from IPython.display import Markdown, display
-from fast_ml.utilities import printmd , display_all, normality_diagnostic , plot_categories , \
+from fast_ml.utilities import printmd , normality_diagnostic , plot_categories , \
 plot_categories_with_target , calculate_mean_target_per_category , plot_target_with_categories, \
 get_plot_df, plot_categories_overall_eventrate, plot_categories_within_eventrate
 
 
+
 ################################################################################
 #                                     OVERALL
 ################################################################################
