@@ -2,6 +2,7 @@ import pandas as pd
 import numpy as np
 from joblib import dump, load
 from sklearn import metrics
+from sklearn.model_selection import train_test_split
 import time
 
 
@@ -14,6 +15,13 @@ def model_load (model_name):
 
     return load(file_name)
 
+def get_fi(model, X):
+    fi = pd.DataFrame(model.feature_importances_, X.columns, columns=['feature_imp'])
+    fi.sort_values(by ='feature_imp', ascending=False, inplace=True)
+    fi['cum_fi'] = fi['feature_imp'].cumsum()
+    fi['cum_perc'] = fi['cum_fi']/fi['feature_imp'].sum()
+    return fi
+
 
 def plot_confidence_interval_for_data (model, X):
     """
@@ -122,7 +130,7 @@ def threshold_evaluation(y_true, y_prob, start=0, end=1, step_size=0.1):
                          'Recall Score', 'F1 Score', 'ROC AUC Score']
     return result_df
 
-def metrics_evaluation(y_true, y_prob, threshold, df_type='train'):
+def metrics_evaluation(y_true, y_pred_prob=None, y_pred=None, threshold=None, df_type='train'):
     """
     This function produces various model evaluation metrics at various values of threshold. 
     The values of threshold are customizable using parameters 'start', 'end', 'nsteps'
@@ -130,7 +138,8 @@ def metrics_evaluation(y_true, y_prob, threshold, df_type='train'):
     Parameters:
     -----------
         y_true : 'array', actual value of y (this could be y_train, y_valid, or y_test)
-        y_prob : 'array', predicted value of y (this could be from train, valid or test)
+        y_pred_prob : 'array', predicted probability of y (this could be from train, valid or test)
+        y_pred : 'array', predicted value of y (this could be from train, valid or test)
         threshold : 'float', threshold value at which predicted probability needs to be converted to predictions
         df_type : 'str', Usual values are 'train', 'valid, 'test'
 
@@ -138,8 +147,10 @@ def metrics_evaluation(y_true, y_prob, threshold, df_type='train'):
     --------
         result : 'list', list with various model evaluation metrics 
     """
+    input_y_pred = y_pred 
 
-    y_pred = (y_prob>=threshold).astype(int)
+    if input_y_pred is None:
+        y_pred = (y_pred_prob>=threshold).astype(int)
     
     tn = metrics.confusion_matrix(y_true, y_pred)[0][0]
     fp = metrics.confusion_matrix(y_true, y_pred)[0][1]
@@ -150,7 +161,11 @@ def metrics_evaluation(y_true, y_prob, threshold, df_type='train'):
     precision_scr = metrics.precision_score(y_true, y_pred)
     recall_scr = metrics.recall_score(y_true, y_pred)
     f1_scr = metrics.f1_score(y_true, y_pred)
-    roc_auc_scr = metrics.roc_auc_score(y_true, y_pred)
+    
+    if input_y_pred is None:
+        roc_auc_scr = metrics.roc_auc_score(y_true, y_pred)
+    else:
+        roc_auc_scr = np.nan
 
     result = {'Dataset': df_type, 'No obs': len(y_true), 'Threshold': threshold,
               'TP':tp, 'FP': fp, 'TN': tn, 'FN':fn , 
@@ -159,43 +174,4 @@ def metrics_evaluation(y_true, y_prob, threshold, df_type='train'):
 
     return result
 
-def execute_model(model, model_name, X_train, y_train, X_valid, y_valid, X_test, y_test, eval_metrics='ROC AUC Score'):
-    model_results = []
-    start = time.perf_counter()
-    #Training
-    model.fit(X_train, y_train)
-    
-    #Predict
-    y_train_prob = model.predict_proba(X_train)[:,1]
-    y_valid_prob = model.predict_proba(X_valid)[:,1]
-    y_test_prob = model.predict_proba(X_test)[:,1]
-    
-    #Calculate threshold
-    valid_result_df = threshold_evaluation(y_true=y_valid, y_prob=y_valid_prob, start=0, end=1, step_size=.05)
-    id_max = valid_result_df[eval_metrics].idxmax()
-    threshold = valid_result_df.loc[id_max, 'Threshold']
 
-    end = time.perf_counter()
-    run_time= round(end-start, 2)
-
-    train_res = metrics_evaluation(y_true=y_train, y_prob=y_train_prob, threshold=threshold, df_type='train')
-    train_res['Algorithm'] = model_name
-    train_res['Run Time'] = run_time
-    model_results.append(train_res)
-
-    valid_res = metrics_evaluation(y_true=y_valid, y_prob=y_valid_prob, threshold=threshold, df_type='valid')
-    valid_res['Algorithm'] = model_name
-    valid_res['Run Time'] = run_time
-    model_results.append(valid_res)
-
-    test_res= metrics_evaluation(y_true=y_test, y_prob=y_test_prob, threshold=threshold, df_type='test')
-    test_res['Algorithm'] = model_name
-    test_res['Run Time'] = run_time
-    model_results.append(test_res)
-
-    #print(model_results)
-    model_results_df = pd.DataFrame(model_results)
-    model_results_df = model_results_df[['Algorithm', 'Run Time', 'Dataset', 'No obs', 'Threshold',
-                                     'TP', 'FP', 'TN', 'FN' , 'Accuracy Score', 'Precision Score', 
-                                     'Recall Score', 'F1 Score', 'ROC AUC Score']]
-    return model_results_df
